summaryrefslogtreecommitdiff
path: root/bfd/coff-or32.c
diff options
context:
space:
mode:
authorAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:25 +0000
committerAlan Modra <amodra@bigpond.net.au>2003-06-25 06:40:25 +0000
commit13bc6701a7ec432cfab9aa76f954eb9619b59572 (patch)
treed18138163ceec020b0d615db75516a0fe239913e /bfd/coff-or32.c
parent1a0c77687a77a46d904b2823b24ba90aa40e36b6 (diff)
downloadgdb-13bc6701a7ec432cfab9aa76f954eb9619b59572.tar.gz
Correct spelling of "relocatable".
Diffstat (limited to 'bfd/coff-or32.c')
-rw-r--r--bfd/coff-or32.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/bfd/coff-or32.c b/bfd/coff-or32.c
index 6bec813e13f..b21cdf3f4ad 100644
--- a/bfd/coff-or32.c
+++ b/bfd/coff-or32.c
@@ -1,5 +1,5 @@
/* BFD back-end for OpenRISC 1000 COFF binaries.
- Copyright 2002 Free Software Foundation, Inc.
+ Copyright 2002, 2003 Free Software Foundation, Inc.
Contributed by Ivan Guzvinec <ivang@opencores.org>
This file is part of BFD, the Binary File Descriptor library.
@@ -360,10 +360,10 @@ coff_or32_relocate_section (output_bfd, info, input_bfd, input_section,
bfd_boolean hihalf;
bfd_vma hihalf_val;
/* If we are performing a relocateable link, we don't need to do a
thing. The caller will take care of adjusting the reloc
addresses and symbol indices. */
- if (info->relocateable)
+ if (info->relocatable)
return TRUE;
hihalf = FALSE;
@@ -360,10 +360,10 @@ coff_or32_relocate_section (output_bfd, info, input_bfd, input_section,
bfd_boolean hihalf;
bfd_vma hihalf_val;
- /* If we are performing a relocateable link, we don't need to do a
+ /* If we are performing a relocatable link, we don't need to do a
thing. The caller will take care of adjusting the reloc
addresses and symbol indices. */